/*
 *  C++ core and functions for BASIN.
 *  Copyright (C) 2006  BASIN team
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/*! \file Context.h

*/
#ifndef CONTEXT_H
#define CONTEXT_H

#include "basin_base.h"
class Data;
class List;
class Grid;

using namespace std;

enum Context_Order_Type {NORMAL, FFT_HALF_HERMITIAN};

class Context
{
  public:
  Context();
  Context(const Context& c);
  Context(vector<double> ll, vector<double> ur,vector<int> nx, Data* parent);


  void set_n_grid_points(vector<int> nxyz); 
  vector<int> get_n_grid_points() const;
  vector<int> get_index(int i=0);

  void set_boundary(vector<double> ll,vector<double> ur); 
  vector<vector<double> > get_boundary() const;

  void set_LowerCorner(const vector<double> ll);
  void set_UpperCorner(const vector<double> ur);
  vector<double> get_LowerCorner() const;
  vector<double> get_UpperCorner() const;

  void set_parent(Data* parent);
  Data* get_parentData_pointer() const;
  List* get_parentList_pointer() const;
  Grid* get_parentGrid_pointer() const;
  void set_order_type(int t);
  int get_order_type() const;

 private:
  vector<double>  lower_left_corner;
  vector<double>  upper_right_corner;
  vector<int>     n_grid_points;
  Data *parent;
  int order_type;
};

#endif
